@@ -1,18 +1,25 @@
-class InvalidRoute(Exception):
+class OBRequestsException(Exception):
+    """Base exception.
+    """
+
+    pass
+
+
+class InvalidRoute(OBRequestsException):
     """Raised when route isn't a route object.
     """
 
     pass
 
 
-class InvalidMethod(Exception):
+class InvalidMethod(OBRequestsException):
     """Raised when method is invalid
     """
 
     pass
 
 
-class InvalidResponse(Exception):
+class InvalidResponse(OBRequestsException):
     """ Raised when OBRequests doesn't
         Understand the response object.
     """
